@@ -83,42 +83,104 @@ namespace Model
 
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>Specifies whether a stage is managed by API Gateway. If you created an API
+     * using quick create, the $default stage is managed by API Gateway. You can't
+     * modify the $default stage.</p>
+     */
+    inline bool GetApiGatewayManaged() const{ return m_apiGatewayManaged; }
+
+    /**
+     * <p>Specifies whether a stage is managed by API Gateway. If you created an API
+     * using quick create, the $default stage is managed by API Gateway. You can't
+     * modify the $default stage.</p>
+     */
+    inline bool ApiGatewayManagedHasBeenSet() const { return m_apiGatewayManagedHasBeenSet; }
+
+    /**
+     * <p>Specifies whether a stage is managed by API Gateway. If you created an API
+     * using quick create, the $default stage is managed by API Gateway. You can't
+     * modify the $default stage.</p>
+     */
+    inline void SetApiGatewayManaged(bool value) { m_apiGatewayManagedHasBeenSet = true; m_apiGatewayManaged = value; }
+
+    /**
+     * <p>Specifies whether a stage is managed by API Gateway. If you created an API
+     * using quick create, the $default stage is managed by API Gateway. You can't
+     * modify the $default stage.</p>
+     */
+    inline Stage& WithApiGatewayManaged(bool value) { SetApiGatewayManaged(value); return *this;}
+
+
+    /**
+     * <p>Specifies whether updates to an API automatically trigger a new deployment.
+     * The default value is false.</p>
+     */
+    inline bool GetAutoDeploy() const{ return m_autoDeploy; }
+
+    /**
+     * <p>Specifies whether updates to an API automatically trigger a new deployment.
+     * The default value is false.</p>
+     */
+    inline bool AutoDeployHasBeenSet() const { return m_autoDeployHasBeenSet; }
+
+    /**
+     * <p>Specifies whether updates to an API automatically trigger a new deployment.
+     * The default value is false.</p>
+     */
+    inline void SetAutoDeploy(bool value) { m_autoDeployHasBeenSet = true; m_autoDeploy = value; }
+
+    /**
+     * <p>Specifies whether updates to an API automatically trigger a new deployment.
+     * The default value is false.</p>
+     */
+    inline Stage& WithAutoDeploy(bool value) { SetAutoDeploy(value); return *this;}
+
+
+    /**
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline const Aws::String& GetClientCertificateId() const{ return m_clientCertificateId; }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline bool ClientCertificateIdHasBeenSet() const { return m_clientCertificateIdHasBeenSet; }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetClientCertificateId(const Aws::String& value) { m_clientCertificateIdHasBeenSet = true; m_clientCertificateId = value; }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetClientCertificateId(Aws::String&& value) { m_clientCertificateIdHasBeenSet = true; m_clientCertificateId = std::move(value); }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetClientCertificateId(const char* value) { m_clientCertificateIdHasBeenSet = true; m_clientCertificateId.assign(value); }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline Stage& WithClientCertificateId(const Aws::String& value) { SetClientCertificateId(value); return *this;}
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline Stage& WithClientCertificateId(Aws::String&& value) { SetClientCertificateId(std::move(value)); return *this;}
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline Stage& WithClientCertificateId(const char* value) { SetClientCertificateId(value); return *this;}
 
@@ -186,50 +248,50 @@ namespace Model
 
 
     /**
-     * <p>The identifier of the Deployment that the Stage is
- associated with.</p>
+     * <p>The identifier of the Deployment that the Stage is associated with. Can't be
+     * updated if autoDeploy is enabled.</p>
      */
     inline const Aws::String& GetDeploymentId() const{ return m_deploymentId; }
 
     /**
-     * <p>The identifier of the Deployment that the Stage is
- associated with.</p>
+     * <p>The identifier of the Deployment that the Stage is associated with. Can't be
+     * updated if autoDeploy is enabled.</p>
      */
     inline bool DeploymentIdHasBeenSet() const { return m_deploymentIdHasBeenSet; }
 
     /**
-     * <p>The identifier of the Deployment that the Stage is
- associated with.</p>
+     * <p>The identifier of the Deployment that the Stage is associated with. Can't be
+     * updated if autoDeploy is enabled.</p>
      */
     inline void SetDeploymentId(const Aws::String& value) { m_deploymentIdHasBeenSet = true; m_deploymentId = value; }
 
     /**
-     * <p>The identifier of the Deployment that the Stage is
- associated with.</p>
+     * <p>The identifier of the Deployment that the Stage is associated with. Can't be
+     * updated if autoDeploy is enabled.</p>
      */
     inline void SetDeploymentId(Aws::String&& value) { m_deploymentIdHasBeenSet = true; m_deploymentId = std::move(value); }
 
     /**
-     * <p>The identifier of the Deployment that the Stage is
- associated with.</p>
+     * <p>The identifier of the Deployment that the Stage is associated with. Can't be
+     * updated if autoDeploy is enabled.</p>
      */
     inline void SetDeploymentId(const char* value) { m_deploymentIdHasBeenSet = true; m_deploymentId.assign(value); }
 
     /**
-     * <p>The identifier of the Deployment that the Stage is
- associated with.</p>
+     * <p>The identifier of the Deployment that the Stage is associated with. Can't be
+     * updated if autoDeploy is enabled.</p>
      */
     inline Stage& WithDeploymentId(const Aws::String& value) { SetDeploymentId(value); return *this;}
 
     /**
-     * <p>The identifier of the Deployment that the Stage is
- associated with.</p>
+     * <p>The identifier of the Deployment that the Stage is associated with. Can't be
+     * updated if autoDeploy is enabled.</p>
      */
     inline Stage& WithDeploymentId(Aws::String&& value) { SetDeploymentId(std::move(value)); return *this;}
 
     /**
-     * <p>The identifier of the Deployment that the Stage is
- associated with.</p>
+     * <p>The identifier of the Deployment that the Stage is associated with. Can't be
+     * updated if autoDeploy is enabled.</p>
      */
     inline Stage& WithDeploymentId(const char* value) { SetDeploymentId(value); return *this;}
 
@@ -275,6 +337,55 @@ namespace Model
     inline Stage& WithDescription(const char* value) { SetDescription(value); return *this;}
 
 
+    /**
+     * <p>Describes the status of the last deployment of a stage. Supported only for
+     * stages with autoDeploy enabled.</p>
+     */
+    inline const Aws::String& GetLastDeploymentStatusMessage() const{ return m_lastDeploymentStatusMessage; }
+
+    /**
+     * <p>Describes the status of the last deployment of a stage. Supported only for
+     * stages with autoDeploy enabled.</p>
+     */
+    inline bool LastDeploymentStatusMessageHasBeenSet() const { return m_lastDeploymentStatusMessageHasBeenSet; }
+
+    /**
+     * <p>Describes the status of the last deployment of a stage. Supported only for
+     * stages with autoDeploy enabled.</p>
+     */
+    inline void SetLastDeploymentStatusMessage(const Aws::String& value) { m_lastDeploymentStatusMessageHasBeenSet = true; m_lastDeploymentStatusMessage = value; }
+
+    /**
+     * <p>Describes the status of the last deployment of a stage. Supported only for
+     * stages with autoDeploy enabled.</p>
+     */
+    inline void SetLastDeploymentStatusMessage(Aws::String&& value) { m_lastDeploymentStatusMessageHasBeenSet = true; m_lastDeploymentStatusMessage = std::move(value); }
+
+    /**
+     * <p>Describes the status of the last deployment of a stage. Supported only for
+     * stages with autoDeploy enabled.</p>
+     */
+    inline void SetLastDeploymentStatusMessage(const char* value) { m_lastDeploymentStatusMessageHasBeenSet = true; m_lastDeploymentStatusMessage.assign(value); }
+
+    /**
+     * <p>Describes the status of the last deployment of a stage. Supported only for
+     * stages with autoDeploy enabled.</p>
+     */
+    inline Stage& WithLastDeploymentStatusMessage(const Aws::String& value) { SetLastDeploymentStatusMessage(value); return *this;}
+
+    /**
+     * <p>Describes the status of the last deployment of a stage. Supported only for
+     * stages with autoDeploy enabled.</p>
+     */
+    inline Stage& WithLastDeploymentStatusMessage(Aws::String&& value) { SetLastDeploymentStatusMessage(std::move(value)); return *this;}
+
+    /**
+     * <p>Describes the status of the last deployment of a stage. Supported only for
+     * stages with autoDeploy enabled.</p>
+     */
+    inline Stage& WithLastDeploymentStatusMessage(const char* value) { SetLastDeploymentStatusMessage(value); return *this;}
+
+
     /**
      * <p>The timestamp when the stage was last updated.</p>
      */
@@ -307,62 +418,62 @@ namespace Model
 
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline const Aws::Map<Aws::String, RouteSettings>& GetRouteSettings() const{ return m_routeSettings; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline bool RouteSettingsHasBeenSet() const { return m_routeSettingsHasBeenSet; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline void SetRouteSettings(const Aws::Map<Aws::String, RouteSettings>& value) { m_routeSettingsHasBeenSet = true; m_routeSettings = value; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline void SetRouteSettings(Aws::Map<Aws::String, RouteSettings>&& value) { m_routeSettingsHasBeenSet = true; m_routeSettings = std::move(value); }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline Stage& WithRouteSettings(const Aws::Map<Aws::String, RouteSettings>& value) { SetRouteSettings(value); return *this;}
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline Stage& WithRouteSettings(Aws::Map<Aws::String, RouteSettings>&& value) { SetRouteSettings(std::move(value)); return *this;}
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline Stage& AddRouteSettings(const Aws::String& key, const RouteSettings& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(key, value); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline Stage& AddRouteSettings(Aws::String&& key, const RouteSettings& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline Stage& AddRouteSettings(const Aws::String& key, RouteSettings&& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline Stage& AddRouteSettings(Aws::String&& key, RouteSettings&& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline Stage& AddRouteSettings(const char* key, RouteSettings&& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline Stage& AddRouteSettings(const char* key, const RouteSettings& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(key, value); return *this; }
 
@@ -410,210 +521,171 @@ namespace Model
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline const Aws::Map<Aws::String, Aws::String>& GetStageVariables() const{ return m_stageVariables; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline bool StageVariablesHasBeenSet() const { return m_stageVariablesHasBeenSet; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline void SetStageVariables(const Aws::Map<Aws::String, Aws::String>& value) { m_stageVariablesHasBeenSet = true; m_stageVariables = value; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline void SetStageVariables(Aws::Map<Aws::String, Aws::String>&& value) { m_stageVariablesHasBeenSet = true; m_stageVariables = std::move(value); }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& WithStageVariables(const Aws::Map<Aws::String, Aws::String>& value) { SetStageVariables(value); return *this;}
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& WithStageVariables(Aws::Map<Aws::String, Aws::String>&& value) { SetStageVariables(std::move(value)); return *this;}
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& AddStageVariables(const Aws::String& key, const Aws::String& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(key, value); return *this; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& AddStageVariables(Aws::String&& key, const Aws::String& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(std::move(key), value); return *this; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& AddStageVariables(const Aws::String& key, Aws::String&& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(key, std::move(value)); return *this; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& AddStageVariables(Aws::String&& key, Aws::String&& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& AddStageVariables(const char* key, Aws::String&& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(key, std::move(value)); return *this; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& AddStageVariables(Aws::String&& key, const char* value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(std::move(key), value); return *this; }
 
     /**
      * <p>A map that defines the stage variables for a stage resource. Variable names
-     * can
- have alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * can have alphanumeric and underscore characters, and the values must match
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline Stage& AddStageVariables(const char* key, const char* value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(key, value); return *this; }
 
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline Stage& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
@@ -622,6 +694,12 @@ namespace Model
     AccessLogSettings m_accessLogSettings;
     bool m_accessLogSettingsHasBeenSet;
 
+    bool m_apiGatewayManaged;
+    bool m_apiGatewayManagedHasBeenSet;
+
+    bool m_autoDeploy;
+    bool m_autoDeployHasBeenSet;
+
     Aws::String m_clientCertificateId;
     bool m_clientCertificateIdHasBeenSet;
 
@@ -637,6 +715,9 @@ namespace Model
     Aws::String m_description;
     bool m_descriptionHasBeenSet;
 
+    Aws::String m_lastDeploymentStatusMessage;
+    bool m_lastDeploymentStatusMessageHasBeenSet;
+
     Aws::Utils::DateTime m_lastUpdatedDate;
     bool m_lastUpdatedDateHasBeenSet;
 
