@@ -25,6 +25,7 @@
 #include <aws/mq/model/EngineType.h>
 #include <aws/mq/model/LogsSummary.h>
 #include <aws/mq/model/WeeklyStartTime.h>
+#include <aws/mq/model/BrokerStorageType.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/mq/model/BrokerInstance.h>
 #include <aws/mq/model/UserSummary.h>
@@ -588,47 +589,6 @@ namespace Model
     inline DescribeBrokerResult& WithPendingEngineVersion(const char* value) { SetPendingEngineVersion(value); return *this;}
 
 
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline const Aws::Vector<Aws::String>& GetPendingSecurityGroups() const{ return m_pendingSecurityGroups; }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline void SetPendingSecurityGroups(const Aws::Vector<Aws::String>& value) { m_pendingSecurityGroups = value; }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline void SetPendingSecurityGroups(Aws::Vector<Aws::String>&& value) { m_pendingSecurityGroups = std::move(value); }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& WithPendingSecurityGroups(const Aws::Vector<Aws::String>& value) { SetPendingSecurityGroups(value); return *this;}
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& WithPendingSecurityGroups(Aws::Vector<Aws::String>&& value) { SetPendingSecurityGroups(std::move(value)); return *this;}
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& AddPendingSecurityGroups(const Aws::String& value) { m_pendingSecurityGroups.push_back(value); return *this; }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& AddPendingSecurityGroups(Aws::String&& value) { m_pendingSecurityGroups.push_back(std::move(value)); return *this; }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& AddPendingSecurityGroups(const char* value) { m_pendingSecurityGroups.push_back(value); return *this; }
-
-
     /**
      * The host instance type of the broker to upgrade to. For a list of supported
      * instance types, see
@@ -679,6 +639,47 @@ namespace Model
     inline DescribeBrokerResult& WithPendingHostInstanceType(const char* value) { SetPendingHostInstanceType(value); return *this;}
 
 
+    /**
+     * The list of pending security groups to authorize connections to brokers.
+     */
+    inline const Aws::Vector<Aws::String>& GetPendingSecurityGroups() const{ return m_pendingSecurityGroups; }
+
+    /**
+     * The list of pending security groups to authorize connections to brokers.
+     */
+    inline void SetPendingSecurityGroups(const Aws::Vector<Aws::String>& value) { m_pendingSecurityGroups = value; }
+
+    /**
+     * The list of pending security groups to authorize connections to brokers.
+     */
+    inline void SetPendingSecurityGroups(Aws::Vector<Aws::String>&& value) { m_pendingSecurityGroups = std::move(value); }
+
+    /**
+     * The list of pending security groups to authorize connections to brokers.
+     */
+    inline DescribeBrokerResult& WithPendingSecurityGroups(const Aws::Vector<Aws::String>& value) { SetPendingSecurityGroups(value); return *this;}
+
+    /**
+     * The list of pending security groups to authorize connections to brokers.
+     */
+    inline DescribeBrokerResult& WithPendingSecurityGroups(Aws::Vector<Aws::String>&& value) { SetPendingSecurityGroups(std::move(value)); return *this;}
+
+    /**
+     * The list of pending security groups to authorize connections to brokers.
+     */
+    inline DescribeBrokerResult& AddPendingSecurityGroups(const Aws::String& value) { m_pendingSecurityGroups.push_back(value); return *this; }
+
+    /**
+     * The list of pending security groups to authorize connections to brokers.
+     */
+    inline DescribeBrokerResult& AddPendingSecurityGroups(Aws::String&& value) { m_pendingSecurityGroups.push_back(std::move(value)); return *this; }
+
+    /**
+     * The list of pending security groups to authorize connections to brokers.
+     */
+    inline DescribeBrokerResult& AddPendingSecurityGroups(const char* value) { m_pendingSecurityGroups.push_back(value); return *this; }
+
+
     /**
      * Required. Enables connections from applications outside of the VPC that hosts
      * the broker's subnets.
@@ -699,54 +700,80 @@ namespace Model
 
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorize connections to
-     * brokers.
+     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * to brokers.
      */
     inline const Aws::Vector<Aws::String>& GetSecurityGroups() const{ return m_securityGroups; }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorize connections to
-     * brokers.
+     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * to brokers.
      */
     inline void SetSecurityGroups(const Aws::Vector<Aws::String>& value) { m_securityGroups = value; }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorize connections to
-     * brokers.
+     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * to brokers.
      */
     inline void SetSecurityGroups(Aws::Vector<Aws::String>&& value) { m_securityGroups = std::move(value); }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorize connections to
-     * brokers.
+     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * to brokers.
      */
     inline DescribeBrokerResult& WithSecurityGroups(const Aws::Vector<Aws::String>& value) { SetSecurityGroups(value); return *this;}
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorize connections to
-     * brokers.
+     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * to brokers.
      */
     inline DescribeBrokerResult& WithSecurityGroups(Aws::Vector<Aws::String>&& value) { SetSecurityGroups(std::move(value)); return *this;}
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorize connections to
-     * brokers.
+     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * to brokers.
      */
     inline DescribeBrokerResult& AddSecurityGroups(const Aws::String& value) { m_securityGroups.push_back(value); return *this; }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorize connections to
-     * brokers.
+     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * to brokers.
      */
     inline DescribeBrokerResult& AddSecurityGroups(Aws::String&& value) { m_securityGroups.push_back(std::move(value)); return *this; }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorize connections to
-     * brokers.
+     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * to brokers.
      */
     inline DescribeBrokerResult& AddSecurityGroups(const char* value) { m_securityGroups.push_back(value); return *this; }
 
 
+    /**
+     * The broker's storage type.
+     */
+    inline const BrokerStorageType& GetStorageType() const{ return m_storageType; }
+
+    /**
+     * The broker's storage type.
+     */
+    inline void SetStorageType(const BrokerStorageType& value) { m_storageType = value; }
+
+    /**
+     * The broker's storage type.
+     */
+    inline void SetStorageType(BrokerStorageType&& value) { m_storageType = std::move(value); }
+
+    /**
+     * The broker's storage type.
+     */
+    inline DescribeBrokerResult& WithStorageType(const BrokerStorageType& value) { SetStorageType(value); return *this;}
+
+    /**
+     * The broker's storage type.
+     */
+    inline DescribeBrokerResult& WithStorageType(BrokerStorageType&& value) { SetStorageType(std::move(value)); return *this;}
+
+
     /**
      * The list of groups (2 maximum) that define which subnets and IP ranges the
      * broker can use from different Availability Zones. A SINGLE_INSTANCE deployment
@@ -942,14 +969,16 @@ namespace Model
 
     Aws::String m_pendingEngineVersion;
 
-    Aws::Vector<Aws::String> m_pendingSecurityGroups;
-
     Aws::String m_pendingHostInstanceType;
 
+    Aws::Vector<Aws::String> m_pendingSecurityGroups;
+
     bool m_publiclyAccessible;
 
     Aws::Vector<Aws::String> m_securityGroups;
 
+    BrokerStorageType m_storageType;
+
     Aws::Vector<Aws::String> m_subnetIds;
 
     Aws::Map<Aws::String, Aws::String> m_tags;
